#!/usr/bin/python3
# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='metrics',
    version='0.0.2',
    description='PyPi package created by Schibsted\'s Product & Application Security team.',
    long_description='',
    url='https://schibsted.com',
    author='Product Security Team',
    author_email='application-security+pypi@schibsted.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
